/**
 * Interface representing a slice of text with start and end positions.
 * Optionally includes a matched flag to indicate if this slice matches search criteria.
 *
 * @interface
 * @property {number} start - The starting index of the slice
 * @property {number} end - The ending index of the slice
 * @property {boolean} [matched] - Optional flag indicating if this slice matches search criteria
 *
 * @example
 * // Basic slice without matched flag
 * const slice: Slice = {
 *   start: 0,
 *   end: 5
 * };
 *
 * @example
 * // Slice with matched flag
 * const matchedSlice: Slice = {
 *   start: 10,
 *   end: 15,
 *   matched: true
 * };
 */
interface Slice {
    start: number;
    end: number;
    matched?: boolean;
}
/**
 * Type definition for a text slicing function that finds matches for search words in text.
 *
 * @param {string} text - The input text to search within
 * @param {string[]} searchWords - Array of words to search for
 * @param {(word: string) => RegExp} [match] - Optional function to customize how words are matched
 * @returns {Slice[]} Array of slices representing matched positions
 *
 * @example
 * const text = "Hello world";
 * const searchWords = ["Hello"];
 * const customMatch = (word: string) => new RegExp(word, "i");
 *
 * const slices = slicing(text, searchWords, customMatch);
 * // Returns: [{ start: 0, end: 5 }]
 */
type Slicing = (text: string, searchWords: string[], match?: (word: string) => RegExp) => Slice[];
/**
 * Creates slices of text based on search words.
 *
 * @param {string} text - The input text to search within
 * @param {string[]} searchWords - Array of words to search for
 * @param {(word: string) => RegExp} [match] - Optional function to customize how words are matched
 * @returns {Slice[]} Array of slices representing matched positions
 *
 * @example
 * // Basic usage
 * const text = "Hello world, hello there";
 * const searchWords = ["hello", "world"];
 * const result = slicing(text, searchWords);
 * // Result:
 * // [
 * //   { start: 13, end: 18 },
 * //   { start: 6, end: 11 }
 * // ]
 *
 * @example
 * // Custom case-sensitive matching
 * const text = "HELLO hello World";
 * const searchWords = ["hello"];
 * const match = (word) => new RegExp(word, "g");
 * const result = slicing(text, searchWords, match);
 * // Returns: [
 * //   { start: 6, end: 11 }    // Only matches lowercase "hello"
 * // ]
 */
declare const slicing: Slicing;
/**
 * Merges overlapping slices into a single slice.
 *
 * @param {Slice[]} slices - Array of slices to merge
 * @returns {Slice[]} Array of merged slices with no overlaps
 *
 * @example
 * // Merge overlapping slices
 * const slices = [
 *   { start: 0, end: 5 },
 *   { start: 3, end: 8 },
 *   { start: 10, end: 15 }
 * ];
 * const merged = mergeOverlap(slices);
 * // Returns: [
 * //   { start: 0, end: 8 },
 * //   { start: 10, end: 15 }
 * // ]
 *
 * @example
 * // No overlapping slices remain unchanged
 * const slices = [
 *   { start: 0, end: 5 },
 *   { start: 6, end: 10 }
 * ];
 * const merged = mergeOverlap(slices);
 * // Returns: [
 * //   { start: 0, end: 5 },
 * //   { start: 6, end: 10 }
 * // ]
 */
declare const mergeOverlap: (slices: Slice[]) => Slice[];
/**
 * Updates slices with matched status and fills gaps between matched slices.
 *
 * @param {Slice[]} slices - Array of slices to update with matched status
 * @param {number} [textLength=0] - Total length of the text being processed
 * @returns {Slice[]} Array of slices with matched status and filled gaps
 *
 * @example
 * // Basic usage with matched slices
 * const slices = [
 *   { start: 5, end: 10 },
 *   { start: 15, end: 20 }
 * ];
 * const result = fillSliceGaps(slices, 25);
 * // Returns: [
 * //   { start: 0, end: 5, matched: false },    // Gap at start
 * //   { start: 5, end: 10, matched: true },    // First match
 * //   { start: 10, end: 15, matched: false },  // Gap between matches
 * //   { start: 15, end: 20, matched: true },   // Second match
 * //   { start: 20, end: 25, matched: false }   // Gap at end
 * // ]
 *
 * @example
 * // Empty slices array
 * const result = fillSliceGaps([], 10);
 * // Returns: [
 * //   { start: 0, end: 10, matched: false }    // Entire text marked as unmatched
 * // ]
 */
declare const fillSliceGaps: (slices: Slice[], textLength?: number) => Slice[];
/**
 * Processes text to find matches for search words and returns slices with matched status.
 * This function combines slicing, overlap merging, and gap filling operations.
 *
 * @param {string} text - The input text to search within
 * @param {string[]} searchWords - Array of words to search for
 * @param {(word: string) => RegExp} [match] - Optional function to customize how words are matched
 * @returns {Slice[]} Array of slices with matched status and filled gaps
 *
 * @example
 * // Basic usage with multiple search words
 * const text = "Hello world, how are you?";
 * const searchWords = ["hello", "you"];
 * const result = sliceText(text, searchWords);
 * // Returns: [
 * //   { start: 0, end: 5, matched: true },     // "Hello"
 * //   { start: 5, end: 21, matched: false },   // " world, how are "
 * //   { start: 21, end: 24, matched: true },   // "you"
 * //   { start: 24, end: 23, matched: false }   // "?"
 * // ]
 *
 * @example
 * // Custom case-sensitive matching
 * const text = "HELLO hello WORLD";
 * const searchWords = ["hello"];
 * const match = (word) => new RegExp(word, "g");
 * const result = sliceText(text, searchWords, match);
 * // Returns: [
 * //   { start: 0, end: 6, matched: false },    // "HELLO "
 * //   { start: 6, end: 11, matched: true },    // "hello"
 * //   { start: 11, end: 17, matched: false }   // " WORLD"
 * // ]
 */
declare const sliceText: Slicing;

export { type Slice, type Slicing, fillSliceGaps, mergeOverlap, sliceText, slicing };
